@@ -441,7 +441,8 @@ enum memory_type {
 	MEMORY_CUDA,
 	MEMORY_ROCM,
 	MEMORY_NEURON,
-	MEMORY_HL
+	MEMORY_HL,
+	MEMORY_MLU
 };
 
 struct perftest_parameters {
@@ -524,6 +525,7 @@ struct perftest_parameters {
 	int 				recv_post_list;
 	int				duration;
 	int 				use_srq;
+	int 				no_lock;
 	int 				congest_type;
 	int				use_xrc;
 	int				use_rss;
@@ -574,6 +576,7 @@ struct perftest_parameters {
 	int				neuron_core_id;
 	int				use_neuron_dmabuf;
 	char				*hl_device_bus_id;
+	int				mlu_device_id;
 	char				*mmap_file;
 	unsigned long			mmap_offset;
 	/* New test params format pilot. will be used in all flags soon,. */
@@ -636,6 +639,7 @@ struct perftest_parameters {
 	int 				has_source_ip;
 	int 			ah_allocated;
 	int				use_write_with_imm;
+	int				use_unsolicited_write;
 };
 
 struct report_options {
